@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -66,6 +66,8 @@ struct _PhotosBaseManagerClass
   GObjectClass parent_class;
 
   /* virtual methods */
+  gchar *(*get_filter)    (PhotosBaseManager *self, gint flags);
+  gchar *(*get_where)    (PhotosBaseManager *self, gint flags);
   gboolean (*set_active_object)    (PhotosBaseManager *self, GObject *object);
 
   /* signals */
@@ -83,7 +85,9 @@ void                photos_base_manager_clear                    (PhotosBaseMana
 
 GObject            *photos_base_manager_get_active_object        (PhotosBaseManager *self);
 
-gchar              *photos_base_manager_get_filter               (PhotosBaseManager *self);
+gchar              *photos_base_manager_get_all_filter           (PhotosBaseManager *self);
+
+gchar              *photos_base_manager_get_filter               (PhotosBaseManager *self, gint flags);
 
 GObject            *photos_base_manager_get_object_by_id         (PhotosBaseManager *self, const gchar *id);
 
@@ -91,6 +95,10 @@ GHashTable         *photos_base_manager_get_objects              (PhotosBaseMana
 
 guint               photos_base_manager_get_objects_count        (PhotosBaseManager *self);
 
+const gchar        *photos_base_manager_get_title                (PhotosBaseManager *self);
+
+gchar              *photos_base_manager_get_where                (PhotosBaseManager *self, gint flags);
+
 void                photos_base_manager_process_new_objects      (PhotosBaseManager *self, GHashTable *new_objects);
 
 void                photos_base_manager_remove_object            (PhotosBaseManager *self, GObject *object);
