@@ -35,11 +35,9 @@
 #include "photos-collection-manager.h"
 #include "photos-embed.h"
 #include "photos-filterable.h"
-#include "photos-indexing-notification.h"
 #include "photos-item-manager.h"
 #include "photos-mode-controller.h"
 #include "photos-notification-manager.h"
-#include "photos-preview-view.h"
 #include "photos-search-controller.h"
 #include "photos-selection-toolbar.h"
 #include "photos-spinner-box.h"
@@ -69,7 +67,6 @@ struct _PhotosEmbedPrivate
   GCancellable *loader_cancellable;
   GtkWidget *collections;
   GtkWidget *favorites;
-  GtkWidget *indexing_ntfctn;
   GtkWidget *no_results;
   GtkWidget *ntfctn_mngr;
   GtkWidget *overview;
@@ -222,6 +219,7 @@ photos_embed_item_load (GObject *source_object, GAsyncResult *res, gpointer user
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
   PhotosEmbedPrivate *priv = self->priv;
+  GError *error;
   GeglNode *node;
   GtkListStore *model;
   GtkTreePath *current_path;
@@ -229,11 +227,16 @@ photos_embed_item_load (GObject *source_object, GAsyncResult *res, gpointer user
   PhotosWindowMode mode;
 
   photos_embed_clear_load_timer (self);
-
   g_clear_object (&priv->loader_cancellable);
-  node = photos_base_item_load_finish (item, res, NULL);
-  if (node == NULL)
-    goto out;
+
+  error = NULL;
+  node = photos_base_item_load_finish (item, res, &error);
+  if (error != NULL)
+    {
+      g_warning ("Unable to load the item: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
 
   mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
 
@@ -647,7 +650,6 @@ photos_embed_dispose (GObject *object)
 
   g_clear_object (&priv->ntfctn_mngr);
   g_clear_object (&priv->loader_cancellable);
-  g_clear_object (&priv->indexing_ntfctn);
   g_clear_object (&priv->col_mngr);
   g_clear_object (&priv->item_mngr);
   g_clear_object (&priv->src_mngr);
@@ -681,6 +683,7 @@ photos_embed_init (PhotosEmbed *self)
   PhotosSearchbar *searchbar;
   PhotosSearchContextState *state;
   gboolean querying;
+  const gchar *name;
 
   self->priv = photos_embed_get_instance_private (self);
   priv = self->priv;
@@ -716,27 +719,28 @@ photos_embed_init (PhotosEmbed *self)
   priv->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
   gtk_overlay_add_overlay (GTK_OVERLAY (priv->stack_overlay), priv->ntfctn_mngr);
 
-  priv->indexing_ntfctn = g_object_ref_sink (photos_indexing_notification_new ());
-
-  priv->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW);
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->overview, "overview", _("Recent"));
+  priv->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW, _("Recent"));
+  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->overview));
+  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->overview, "overview", name);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->overview));
   g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
   g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
-  priv->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS);
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->collections, "collections", _("Albums"));
+  priv->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS, _("Albums"));
+  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->collections));
+  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->collections, "collections", name);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->collections));
   g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
   g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
-  priv->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES);
-  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->favorites, "favorites", _("Favorites"));
+  priv->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES, _("Favorites"));
+  name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (priv->favorites));
+  gtk_stack_add_titled (GTK_STACK (priv->stack), priv->favorites, "favorites", name);
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->favorites));
   g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
   g_signal_connect_swapped (model, "row-deleted", G_CALLBACK (photos_embed_row_changed), self);
 
-  priv->search = photos_view_container_new (PHOTOS_WINDOW_MODE_SEARCH);
+  priv->search = photos_view_container_new (PHOTOS_WINDOW_MODE_SEARCH, _("Search"));
   gtk_stack_add_named (GTK_STACK (priv->stack), priv->search, "search");
   model = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (priv->search));
   g_signal_connect_swapped (model, "row-inserted", G_CALLBACK (photos_embed_row_changed), self);
@@ -817,3 +821,10 @@ photos_embed_get_main_toolbar (PhotosEmbed *self)
 {
   return PHOTOS_MAIN_TOOLBAR (self->priv->toolbar);
 }
+
+
+PhotosPreviewView *
+photos_embed_get_preview (PhotosEmbed *self)
+{
+  return PHOTOS_PREVIEW_VIEW (self->priv->preview);
+}
