@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013 Red Hat, Inc.
+ * Copyright © 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -154,7 +154,7 @@ photos_header_bar_set_mode (PhotosHeaderBar *self, PhotosHeaderBarMode mode)
 
 
 void
-photos_header_bar_set_selection_menu (PhotosHeaderBar *self, GdHeaderButton *selection_menu)
+photos_header_bar_set_selection_menu (PhotosHeaderBar *self, GtkButton *selection_menu)
 {
   PhotosHeaderBarPrivate *priv = self->priv;
 
