@@ -1,5 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
+ * Copyright © 2014 Pranav Kant
  * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
@@ -41,6 +42,28 @@ G_DEFINE_TYPE_WITH_CODE (PhotosLocalItem, photos_local_item, PHOTOS_TYPE_BASE_IT
                                                          0));
 
 
+static void
+photos_local_item_delete (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhotosLocalItem *self = PHOTOS_LOCAL_ITEM (user_data);
+  GError *error;
+  GFile *file = G_FILE (source_object);
+
+  error = NULL;
+  g_file_delete_finish (file, res, &error);
+  if (error != NULL)
+    {
+      const gchar *uri;
+
+      uri = photos_base_item_get_uri (PHOTOS_BASE_ITEM (self));
+      g_warning ("Unable to delete %s: %s", uri, error->message);
+      g_error_free (error);
+    }
+
+  g_object_unref (self);
+}
+
+
 static gboolean
 photos_local_item_create_thumbnail (PhotosBaseItem *item, GCancellable *cancellable, GError **error)
 {
@@ -108,6 +131,24 @@ photos_local_item_get_source_widget (PhotosBaseItem *item)
 }
 
 
+static void
+photos_local_item_trash (PhotosBaseItem *item)
+{
+  GFile *file;
+  const gchar *uri;
+
+  if (photos_base_item_is_collection (item))
+    return;
+
+  uri = photos_base_item_get_uri (item);
+  file = g_file_new_for_uri (uri);
+  g_file_delete_async (file, G_PRIORITY_DEFAULT, NULL, photos_local_item_delete, g_object_ref (item));
+
+  g_object_unref (file);
+
+}
+
+
 static void
 photos_local_item_constructed (GObject *object)
 {
@@ -149,4 +190,5 @@ photos_local_item_class_init (PhotosLocalItemClass *class)
   base_item_class->create_thumbnail = photos_local_item_create_thumbnail;
   base_item_class->download = photos_local_item_download;
   base_item_class->get_source_widget = photos_local_item_get_source_widget;
+  base_item_class->trash = photos_local_item_trash;
 }
