@@ -29,7 +29,6 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgd/gd.h>
 
 #include "photos-collection-manager.h"
 #include "photos-dlna-renderers-manager.h"
@@ -50,6 +49,7 @@ struct _PhotosMainToolbarPrivate
   GAction *search;
   GSimpleAction *gear_menu;
   GtkWidget *coll_back_button;
+  GtkWidget *favorite_button;
   GtkWidget *overlay;
   GtkWidget *remote_display_button;
   GtkWidget *searchbar;
@@ -73,6 +73,9 @@ enum
 G_DEFINE_TYPE_WITH_PRIVATE (PhotosMainToolbar, photos_main_toolbar, GTK_TYPE_BOX);
 
 
+static void photos_main_toolbar_favorite_button_update (PhotosMainToolbar *self, gboolean favorite);
+
+
 static void
 photos_main_toolbar_set_toolbar_title (PhotosMainToolbar *self)
 {
@@ -133,7 +136,16 @@ photos_main_toolbar_set_toolbar_title (PhotosMainToolbar *self)
     }
 
   if (selection_mode)
-    gd_header_button_set_label (GD_HEADER_BUTTON (priv->selection_menu), primary);
+    {
+      if (primary != NULL)
+        {
+          GtkWidget *label;
+
+          gtk_button_set_label (GTK_BUTTON (priv->selection_menu), primary);
+          label = gtk_bin_get_child (GTK_BIN (priv->selection_menu));
+          gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        }
+    }
   else
     gtk_header_bar_set_title (GTK_HEADER_BAR (priv->toolbar), primary);
 
@@ -147,9 +159,8 @@ photos_main_toolbar_add_back_button (PhotosMainToolbar *self)
   PhotosMainToolbarPrivate *priv = self->priv;
   GtkWidget *back_button;
 
-  back_button = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (back_button), _("Back"));
-  gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (back_button), PHOTOS_ICON_GO_PREVIOUS_SYMBOLIC);
+  back_button = gtk_button_new_from_icon_name (PHOTOS_ICON_GO_PREVIOUS_SYMBOLIC, GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_tooltip_text (back_button, _("Back"));
   gtk_header_bar_pack_start (GTK_HEADER_BAR (priv->toolbar), back_button);
 
   return back_button;
@@ -157,17 +168,15 @@ photos_main_toolbar_add_back_button (PhotosMainToolbar *self)
 
 
 static void
-photos_main_toolbar_coll_back_button_clicked (GtkButton *button, gpointer user_data)
+photos_main_toolbar_coll_back_button_clicked (PhotosMainToolbar *self)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   photos_item_manager_activate_previous_collection (PHOTOS_ITEM_MANAGER (self->priv->item_mngr));
 }
 
 
 static void
-photos_main_toolbar_col_active_changed (PhotosBaseManager *manager, GObject *object, gpointer user_data)
+photos_main_toolbar_col_active_changed (PhotosMainToolbar *self, GObject *object)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   PhotosMainToolbarPrivate *priv = self->priv;
   PhotosHeaderBarMode mode;
 
@@ -179,10 +188,10 @@ photos_main_toolbar_col_active_changed (PhotosBaseManager *manager, GObject *obj
           priv->coll_back_button = photos_main_toolbar_add_back_button (self);
           gtk_widget_show (priv->coll_back_button);
 
-          g_signal_connect (priv->coll_back_button,
-                            "clicked",
-                            G_CALLBACK (photos_main_toolbar_coll_back_button_clicked),
-                            self);
+          g_signal_connect_swapped (priv->coll_back_button,
+                                    "clicked",
+                                    G_CALLBACK (photos_main_toolbar_coll_back_button_clicked),
+                                    self);
         }
     }
   else
@@ -201,34 +210,36 @@ photos_main_toolbar_col_active_changed (PhotosBaseManager *manager, GObject *obj
 
 
 static void
-photos_main_toolbar_item_active_changed (PhotosBaseManager *manager, GObject *object, gpointer user_data)
+photos_main_toolbar_item_active_changed (PhotosMainToolbar *self, GObject *object)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   PhotosMainToolbarPrivate *priv = self->priv;
   PhotosWindowMode window_mode;
+  gboolean favorite;
 
   if (object == NULL)
     return;
 
   window_mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
-  if (window_mode == PHOTOS_WINDOW_MODE_PREVIEW)
-    photos_main_toolbar_set_toolbar_title (self);
+  if (window_mode != PHOTOS_WINDOW_MODE_PREVIEW)
+    return;
+
+  photos_main_toolbar_set_toolbar_title (self);
+
+  favorite = photos_base_item_is_favorite (PHOTOS_BASE_ITEM (object));
+  photos_main_toolbar_favorite_button_update (self, favorite);
 }
 
 
 static void
-photos_main_toolbar_select_button_clicked (GtkButton *button, gpointer user_data)
+photos_main_toolbar_select_button_clicked (PhotosMainToolbar *self)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   photos_selection_controller_set_selection_mode (self->priv->sel_cntrlr, TRUE);
 }
 
 
 static void
-photos_main_toolbar_remote_display_button_clicked (GtkButton *button,
-                                                   gpointer user_data)
+photos_main_toolbar_remote_display_button_clicked (PhotosMainToolbar *self)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   PhotosMainToolbarPrivate *priv = self->priv;
 
   photos_remote_display_manager_stop (priv->remote_mngr);
@@ -251,17 +262,18 @@ photos_main_toolbar_add_remote_display_button (PhotosMainToolbar *self)
   name = photos_dlna_renderer_get_friendly_name (renderer);
   text = g_markup_printf_escaped ("Displaying on <b>%s</b>", name);
 
-  priv->remote_display_button = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->remote_display_button), text);
-  gd_header_button_set_use_markup (GD_HEADER_BUTTON (priv->remote_display_button), TRUE);
+  priv->remote_display_button = gtk_button_new_with_label (text);
   label = GTK_LABEL (gtk_bin_get_child (GTK_BIN (priv->remote_display_button)));
   gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_MIDDLE);
+  gtk_label_set_use_markup (label, TRUE);
   gtk_widget_set_margin_end (priv->remote_display_button, 12);
   gtk_header_bar_pack_start (GTK_HEADER_BAR (priv->toolbar), priv->remote_display_button);
   gtk_widget_show_all (priv->remote_display_button);
 
-  g_signal_connect (priv->remote_display_button, "clicked",
-                    G_CALLBACK (photos_main_toolbar_remote_display_button_clicked), self);
+  g_signal_connect_swapped (priv->remote_display_button,
+                            "clicked",
+                            G_CALLBACK (photos_main_toolbar_remote_display_button_clicked),
+                            self);
   g_free (text);
 }
 
@@ -269,11 +281,13 @@ photos_main_toolbar_add_remote_display_button (PhotosMainToolbar *self)
 static GtkWidget *
 photos_main_toolbar_add_search_button (PhotosMainToolbar *self)
 {
+  GtkWidget *image;
   GtkWidget *search_button;
 
-  search_button = gd_header_toggle_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (search_button), _("Search"));
-  gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (search_button), PHOTOS_ICON_EDIT_FIND_SYMBOLIC);
+  image = gtk_image_new_from_icon_name (PHOTOS_ICON_EDIT_FIND_SYMBOLIC, GTK_ICON_SIZE_BUTTON);
+  search_button = gtk_toggle_button_new ();
+  gtk_widget_set_tooltip_text (search_button, _("Search"));
+  gtk_button_set_image (GTK_BUTTON (search_button), image);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (search_button), "app.search");
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self->priv->toolbar), search_button);
 
@@ -287,26 +301,27 @@ photos_main_toolbar_add_selection_button (PhotosMainToolbar *self)
   PhotosMainToolbarPrivate *priv = self->priv;
   GtkWidget *selection_button;
 
-  selection_button = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (selection_button), _("Select Items"));
-  gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (selection_button), PHOTOS_ICON_OBJECT_SELECT_SYMBOLIC);
+  selection_button = gtk_button_new_from_icon_name (PHOTOS_ICON_OBJECT_SELECT_SYMBOLIC, GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_tooltip_text (selection_button, _("Select Items"));
   gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->toolbar), selection_button);
-  g_signal_connect (selection_button, "clicked", G_CALLBACK (photos_main_toolbar_select_button_clicked), self);
+  g_signal_connect_swapped (selection_button,
+                            "clicked",
+                            G_CALLBACK (photos_main_toolbar_select_button_clicked),
+                            self);
 
   g_signal_connect_object (priv->col_mngr,
                            "active-changed",
                            G_CALLBACK (photos_main_toolbar_col_active_changed),
                            self,
-                           0);
+                           G_CONNECT_SWAPPED);
 
   return selection_button;
 }
 
 
 static void
-photos_main_toolbar_back_button_clicked (GtkButton *button, gpointer user_data)
+photos_main_toolbar_back_button_clicked (PhotosMainToolbar *self)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   PhotosMainToolbarPrivate *priv = self->priv;
 
   photos_base_manager_set_active_object (priv->item_mngr, NULL);
@@ -422,13 +437,55 @@ photos_main_toolbar_create_preview_menu (PhotosMainToolbar *self)
 
 
 static void
-photos_main_toolbar_done_button_clicked (GtkButton *button, gpointer user_data)
+photos_main_toolbar_done_button_clicked (PhotosMainToolbar *self)
 {
-  PhotosMainToolbar *self = PHOTOS_MAIN_TOOLBAR (user_data);
   photos_selection_controller_set_selection_mode (self->priv->sel_cntrlr, FALSE);
 }
 
 
+static void
+photos_main_toolbar_favorite_button_clicked (PhotosMainToolbar *self)
+{
+  PhotosBaseItem *item;
+  gboolean favorite;
+
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->priv->item_mngr));
+  favorite = photos_base_item_is_favorite (item);
+  photos_base_item_set_favorite (item, !favorite);
+
+  photos_main_toolbar_favorite_button_update (self, !favorite);
+}
+
+
+static void
+photos_main_toolbar_favorite_button_update (PhotosMainToolbar *self, gboolean favorite)
+{
+  PhotosMainToolbarPrivate *priv = self->priv;
+  GtkStyleContext *context;
+  gchar *favorite_label;
+
+  g_signal_handlers_block_by_func (priv->favorite_button, photos_main_toolbar_favorite_button_clicked, self);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->favorite_button), favorite);
+  g_signal_handlers_unblock_by_func (priv->favorite_button, photos_main_toolbar_favorite_button_clicked, self);
+
+  context = gtk_widget_get_style_context (priv->favorite_button);
+  if (favorite)
+    {
+      favorite_label = g_strdup (_("Remove from favorites"));
+      gtk_style_context_add_class (context, "photos-favorite");
+    }
+  else
+    {
+      favorite_label = g_strdup (_("Add to favorites"));
+      gtk_style_context_remove_class (context, "photos-favorite");
+    }
+
+  gtk_widget_reset_style (priv->favorite_button);
+  gtk_widget_set_tooltip_text (priv->favorite_button, favorite_label);
+  g_free (favorite_label);
+}
+
+
 static void
 photos_main_toolbar_populate_for_collections (PhotosMainToolbar *self)
 {
@@ -444,7 +501,7 @@ photos_main_toolbar_populate_for_collections (PhotosMainToolbar *self)
     gtk_container_add (GTK_CONTAINER (self), priv->searchbar);
 
   object = photos_base_manager_get_active_object (priv->col_mngr);
-  photos_main_toolbar_col_active_changed (priv->col_mngr, object, self);
+  photos_main_toolbar_col_active_changed (self, object);
 }
 
 
@@ -481,7 +538,7 @@ photos_main_toolbar_populate_for_favorites (PhotosMainToolbar *self)
     gtk_container_add (GTK_CONTAINER (self), priv->searchbar);
 
   object = photos_base_manager_get_active_object (priv->col_mngr);
-  photos_main_toolbar_col_active_changed (priv->col_mngr, object, self);
+  photos_main_toolbar_col_active_changed (self, object);
 }
 
 
@@ -500,7 +557,7 @@ photos_main_toolbar_populate_for_overview (PhotosMainToolbar *self)
     gtk_container_add (GTK_CONTAINER (self), priv->searchbar);
 
   object = photos_base_manager_get_active_object (priv->col_mngr);
-  photos_main_toolbar_col_active_changed (priv->col_mngr, object, self);
+  photos_main_toolbar_col_active_changed (self, object);
 }
 
 
@@ -510,8 +567,11 @@ photos_main_toolbar_populate_for_preview (PhotosMainToolbar *self)
   PhotosMainToolbarPrivate *priv = self->priv;
   GMenu *preview_menu;
   GtkWidget *back_button;
+  GtkWidget *image;
   GtkWidget *menu_button;
   GApplication *app;
+  PhotosBaseItem *item;
+  gboolean favorite;
   gboolean remote_display_available;
   GAction *remote_display_action;
 
@@ -519,17 +579,31 @@ photos_main_toolbar_populate_for_preview (PhotosMainToolbar *self)
   photos_header_bar_set_mode (PHOTOS_HEADER_BAR (priv->toolbar), PHOTOS_HEADER_BAR_MODE_STANDALONE);
 
   back_button = photos_main_toolbar_add_back_button (self);
-  g_signal_connect (back_button, "clicked", G_CALLBACK (photos_main_toolbar_back_button_clicked), self);
+  g_signal_connect_swapped (back_button, "clicked", G_CALLBACK (photos_main_toolbar_back_button_clicked), self);
 
   preview_menu = photos_main_toolbar_create_preview_menu (self);
-  menu_button = gd_header_menu_button_new ();
+  image = gtk_image_new_from_icon_name (PHOTOS_ICON_SYSTEM_SYMBOLIC, GTK_ICON_SIZE_BUTTON);
+  menu_button = gtk_menu_button_new ();
   gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_button), "app.gear-menu");
+  gtk_button_set_image (GTK_BUTTON (menu_button), image);
   gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (menu_button), G_MENU_MODEL (preview_menu));
-  gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (menu_button), PHOTOS_ICON_SYSTEM_SYMBOLIC);
   gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->toolbar), menu_button);
 
   g_simple_action_set_enabled (priv->gear_menu, TRUE);
 
+  image = gtk_image_new_from_icon_name (PHOTOS_ICON_FAVORITE_SYMBOLIC, GTK_ICON_SIZE_BUTTON);
+  priv->favorite_button = gtk_toggle_button_new ();
+  gtk_button_set_image (GTK_BUTTON (priv->favorite_button), image);
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->toolbar), priv->favorite_button);
+  g_signal_connect_swapped (priv->favorite_button,
+                            "clicked",
+                            G_CALLBACK (photos_main_toolbar_favorite_button_clicked),
+                            self);
+
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (priv->item_mngr));
+  favorite = photos_base_item_is_favorite (item);
+  photos_main_toolbar_favorite_button_update (self, favorite);
+
   /* Disable the remote-display-current action if the dLeyna services are not
    * available */
   app = g_application_get_default ();
@@ -537,7 +611,11 @@ photos_main_toolbar_populate_for_preview (PhotosMainToolbar *self)
   remote_display_available = photos_dlna_renderers_manager_is_available ();
   g_simple_action_set_enabled (G_SIMPLE_ACTION (remote_display_action), remote_display_available);
 
-  g_signal_connect (priv->item_mngr, "active-changed", G_CALLBACK (photos_main_toolbar_item_active_changed), self);
+  g_signal_connect_object (priv->item_mngr,
+                           "active-changed",
+                           G_CALLBACK (photos_main_toolbar_item_active_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
 }
 
 
@@ -556,7 +634,7 @@ photos_main_toolbar_populate_for_search (PhotosMainToolbar *self)
     gtk_container_add (GTK_CONTAINER (self), priv->searchbar);
 
   object = photos_base_manager_get_active_object (priv->col_mngr);
-  photos_main_toolbar_col_active_changed (priv->col_mngr, object, self);
+  photos_main_toolbar_col_active_changed (self, object);
 }
 
 
@@ -568,10 +646,12 @@ photos_main_toolbar_populate_for_selection_mode (PhotosMainToolbar *self)
 
   photos_header_bar_set_mode (PHOTOS_HEADER_BAR (priv->toolbar), PHOTOS_HEADER_BAR_MODE_SELECTION);
 
-  selection_button = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (selection_button), _("Cancel"));
+  selection_button = gtk_button_new_with_label (_("Cancel"));
   gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->toolbar), selection_button);
-  g_signal_connect (selection_button, "clicked", G_CALLBACK (photos_main_toolbar_done_button_clicked), self);
+  g_signal_connect_swapped (selection_button,
+                            "clicked",
+                            G_CALLBACK (photos_main_toolbar_done_button_clicked),
+                            self);
 
   g_signal_connect_object (priv->sel_cntrlr,
                            "selection-changed",
@@ -690,13 +770,11 @@ photos_main_toolbar_init (PhotosMainToolbar *self)
   gtk_builder_add_from_resource (builder, "/org/gnome/photos/selection-menu.ui", NULL);
 
   selection_menu = G_MENU (gtk_builder_get_object (builder, "selection-menu"));
-  priv->selection_menu = gd_header_menu_button_new ();
+  priv->selection_menu = gtk_menu_button_new ();
   gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (priv->selection_menu), G_MENU_MODEL (selection_menu));
-  gd_header_button_set_use_markup (GD_HEADER_BUTTON (priv->selection_menu), TRUE);
   g_object_unref (builder);
 
-  photos_header_bar_set_selection_menu (PHOTOS_HEADER_BAR (priv->toolbar),
-                                        GD_HEADER_BUTTON (priv->selection_menu));
+  photos_header_bar_set_selection_menu (PHOTOS_HEADER_BAR (priv->toolbar), GTK_BUTTON (priv->selection_menu));
 
   priv->col_mngr = g_object_ref (state->col_mngr);
   priv->item_mngr = photos_item_manager_dup_singleton ();
