@@ -1,5 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
+ * Copyright © 2014 Pranav Kant
  * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
@@ -27,9 +28,9 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <libgd/gd.h>
 
 #include "photos-base-item.h"
+#include "photos-delete-notification.h"
 #include "photos-icons.h"
 #include "photos-item-manager.h"
 #include "photos-organize-collection-dialog.h"
@@ -280,7 +281,7 @@ photos_selection_toolbar_set_item_visibility (PhotosSelectionToolbar *self)
     /* Translators: this is the Open action in a context menu */
     open_label = g_strdup (_("Open"));
 
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->toolbar_open), open_label);
+  gtk_button_set_label (GTK_BUTTON (priv->toolbar_open), open_label);
   g_free (open_label);
   g_list_free_full (apps, g_free);
 
@@ -374,6 +375,7 @@ photos_selection_toolbar_trash_clicked (GtkButton *button, gpointer user_data)
 {
   PhotosSelectionToolbar *self = PHOTOS_SELECTION_TOOLBAR (user_data);
   PhotosSelectionToolbarPrivate *priv = self->priv;
+  GList *items = NULL;
   GList *selection;
   GList *l;
 
@@ -384,10 +386,22 @@ photos_selection_toolbar_trash_clicked (GtkButton *button, gpointer user_data)
       const gchar *urn = (gchar *) l->data;
 
       item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (priv->item_mngr, urn));
-      photos_base_item_trash (item);
+      items = g_list_prepend (items, g_object_ref (item));
     }
 
+  /* Removing an item from the item manager changes the selection, so
+   * we can't use the selection while removing items.
+   */
+  for (l = items; l != NULL; l = l->next)
+    {
+      PhotosBaseItem *item = PHOTOS_BASE_ITEM (l->data);
+      photos_base_manager_remove_object (priv->item_mngr, G_OBJECT (item));
+    }
+
+  photos_delete_notification_new (items);
   photos_selection_controller_set_selection_mode (priv->sel_cntrlr, FALSE);
+
+  g_list_free_full (items, g_object_unref);
 }
 
 
@@ -414,6 +428,7 @@ static void
 photos_selection_toolbar_init (PhotosSelectionToolbar *self)
 {
   PhotosSelectionToolbarPrivate *priv;
+  GtkWidget *image;
   GtkWidget *toolbar;
 
   self->priv = photos_selection_toolbar_get_instance_private (self);
@@ -424,49 +439,44 @@ photos_selection_toolbar_init (PhotosSelectionToolbar *self)
   toolbar = gtk_action_bar_new ();
   gtk_container_add (GTK_CONTAINER (self), toolbar);
 
-  priv->toolbar_favorite = gd_header_toggle_button_new ();
-  gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (priv->toolbar_favorite),
-                                           PHOTOS_ICON_FAVORITE_SYMBOLIC);
+  image = gtk_image_new_from_icon_name (PHOTOS_ICON_FAVORITE_SYMBOLIC, GTK_ICON_SIZE_BUTTON);
+  priv->toolbar_favorite = gtk_toggle_button_new ();
+  gtk_button_set_image (GTK_BUTTON (priv->toolbar_favorite), image);
   gtk_action_bar_pack_start (GTK_ACTION_BAR (toolbar), priv->toolbar_favorite);
   g_signal_connect (priv->toolbar_favorite,
                     "clicked",
                     G_CALLBACK (photos_selection_toolbar_favorite_clicked),
                     self);
 
-  priv->toolbar_open = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->toolbar_open), _("Open"));
+  priv->toolbar_open = gtk_button_new_with_label (_("Open"));
   gtk_action_bar_pack_start (GTK_ACTION_BAR (toolbar), priv->toolbar_open);
   g_signal_connect (priv->toolbar_open,
                     "clicked",
                     G_CALLBACK (photos_selection_toolbar_open_clicked),
                     self);
 
-  priv->toolbar_print = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->toolbar_print), _("Print"));
+  priv->toolbar_print = gtk_button_new_with_label (_("Print"));
   gtk_action_bar_pack_start (GTK_ACTION_BAR (toolbar), priv->toolbar_print);
   g_signal_connect (priv->toolbar_print,
                     "clicked",
                     G_CALLBACK (photos_selection_toolbar_print_clicked),
                     self);
 
-  priv->toolbar_trash = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->toolbar_trash), _("Delete"));
+  priv->toolbar_trash = gtk_button_new_with_label (_("Delete"));
   gtk_action_bar_pack_start (GTK_ACTION_BAR (toolbar), priv->toolbar_trash);
   g_signal_connect (priv->toolbar_trash,
                     "clicked",
                     G_CALLBACK (photos_selection_toolbar_trash_clicked),
                     self);
 
-  priv->toolbar_properties = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->toolbar_properties), _("Properties"));
+  priv->toolbar_properties = gtk_button_new_with_label (_("Properties"));
   gtk_action_bar_pack_end (GTK_ACTION_BAR (toolbar), priv->toolbar_properties);
   g_signal_connect (priv->toolbar_properties,
                     "clicked",
                     G_CALLBACK (photos_selection_toolbar_properties_clicked),
                     self);
 
-  priv->toolbar_collection = gd_header_simple_button_new ();
-  gd_header_button_set_label (GD_HEADER_BUTTON (priv->toolbar_collection), _("Add to Album"));
+  priv->toolbar_collection = gtk_button_new_with_label (_("Add to Album"));
   gtk_action_bar_pack_end (GTK_ACTION_BAR (toolbar), priv->toolbar_collection);
   g_signal_connect (priv->toolbar_collection,
                     "clicked",
